==> skrooge_0.7.3.2.orig.tar.gz: skrooge-0.7.3.2/skgbankgui/skgunitcomboboxdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE skrooge@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a predicat creator for skrooge (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgunitcomboboxdesignerplugin.h"
#include "skgunitcombobox.h"

#include "kicon.h"

#include <QtPlugin>

SKGUnitComboBoxDesignerPlugin::SKGUnitComboBoxDesignerPlugin(QObject *parent)
        : QObject(parent)
{
    initialized = false;
}

void SKGUnitComboBoxDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
    if (initialized) return;

    initialized = true;
}

bool SKGUnitComboBoxDesignerPlugin::isInitialized() const
{
    return initialized;
}

QWidget *SKGUnitComboBoxDesignerPlugin::createWidget(QWidget *parent)
{
    return new SKGUnitComboBox(parent);
}

QString SKGUnitComboBoxDesignerPlugin::name() const
{
    return "SKGUnitComboBox";
}

QString SKGUnitComboBoxDesignerPlugin::group() const
{
    return "SKG Widgets";
}

QIcon SKGUnitComboBoxDesignerPlugin::icon() const
{
    return KIcon("skrooge.png");
}

QString SKGUnitComboBoxDesignerPlugin::toolTip() const
{
    return "A unit combo box";
}

QString SKGUnitComboBoxDesignerPlugin::whatsThis() const
{
    return "A unit combo box";
}

bool SKGUnitComboBoxDesignerPlugin::isContainer() const
{
    return false;
}

QString SKGUnitComboBoxDesignerPlugin::domXml() const
{
    return "<widget class=\"SKGUnitComboBox\" name=\"SKGUnitComboBox\">\n"
           " <property name=\"geometry\">\n"
           "  <rect>\n"
           "   <x>0</x>\n"
           "   <y>0</y>\n"
           "   <width>100</width>\n"
           "   <height>100</height>\n"
           "  </rect>\n"
           " </property>\n"
           "</widget>\n";
}

QString SKGUnitComboBoxDesignerPlugin::includeFile() const
{
    return "skgunitcombobox.h";
}

==> skrooge_0.9.92.orig.tar.gz: skrooge-0.9.92/skgbankgui/skgunitcomboboxdesignerplugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2008 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>  *
 ***************************************************************************/
/** @file
 * This file is a predicat creator for skrooge (qt designer plugin).
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
 */
#include "skgunitcomboboxdesignerplugin.h"
#include "skgunitcombobox.h"

#include "kicon.h"

#include <QtPlugin>

SKGUnitComboBoxDesignerPlugin::SKGUnitComboBoxDesignerPlugin(QObject *parent)
    : QObject(parent)
{
    m_initialized = false;
}

void SKGUnitComboBoxDesignerPlugin::initialize(QDesignerFormEditorInterface * /* core */)
{
    if(m_initialized) return;

    m_initialized = true;
}

bool SKGUnitComboBoxDesignerPlugin::isInitialized() const
{
    return m_initialized;
}

QWidget *SKGUnitComboBoxDesignerPlugin::createWidget(QWidget *parent)
{
    return new SKGUnitComboBox(parent);
}

QString SKGUnitComboBoxDesignerPlugin::name() const
{
    return "SKGUnitComboBox";
}

QString SKGUnitComboBoxDesignerPlugin::group() const
{
    return "SKG Widgets";
}

QIcon SKGUnitComboBoxDesignerPlugin::icon() const
{
    return KIcon("skrooge.png");
}

QString SKGUnitComboBoxDesignerPlugin::toolTip() const
{
    return "A unit combo box";
}

QString SKGUnitComboBoxDesignerPlugin::whatsThis() const
{
    return "A unit combo box";
}

bool SKGUnitComboBoxDesignerPlugin::isContainer() const
{
    return false;
}

QString SKGUnitComboBoxDesignerPlugin::domXml() const
{
    return "<widget class=\"SKGUnitComboBox\" name=\"SKGUnitComboBox\">\n"
           " <property name=\"geometry\">\n"
           "  <rect>\n"
           "   <x>0</x>\n"
           "   <y>0</y>\n"
           "   <width>100</width>\n"
           "   <height>100</height>\n"
           "  </rect>\n"
           " </property>\n"
           "</widget>\n";
}

QString SKGUnitComboBoxDesignerPlugin::includeFile() const
{
    return "skgunitcombobox.h";
}
